# Copyright 1999-2007 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: $

inherit eutils toolchain-funcs

DESCRIPTION="Cross Platform Integrated Development Environment"
SRC_URI="http://downloads.sourceforge.net/upp/upp_2007.1-beta3.tar.gz"
HOMEPAGE="http://www.ultimatepp.org/"

#LICENSE="What License? GPL-2 LGPL-2.1"
LICENSE="GPL-2 LGPL-2.1"
SLOT="0"
KEYWORDS="~amd64 ~ppc ~sparc x86"
INSTALLDIR="/opt/upp"

IUSE="threads truetype gtk2"
DEPEND="gtk2? ( >=x11-libs/gtk+-2
					x11-libs/pango
					x11-libs/cairo
					dev-libs/atk )
				truetype? ( media-libs/freetype )
				media-libs/fontconfig"

src_unpack() {
	unpack ${A} || die "Unpacking ${A} failed!"

	einfo "Fixing Makefiles..."
	cp "${FILESDIR}/Makefile.head_b3" "${WORKDIR}/Makefile" || die
	cp "${FILESDIR}/Makefile.ide_b3" "${WORKDIR}/uppsrc/ide/Makefile" || die
}

src_compile() {
	cd ${WORKDIR}

	local CINC
	local LIBS
	local UPPDIR1

	UPPDIR1="uppsrc/"

	CINC="-I${UPPDIR1}"
	LIBS=""
	if use truetype ; then
		CINC="${CINC} `freetype-config --cflags`"
		LIBS="${LIBS} `freetype-config --libs`"
	fi

	if use gtk2 ; then
		CINC="${CINC} `pkg-config gtk+-2.0 --cflags`"
		LIBS="${LIBS} `pkg-config gtk+-2.0 --libs`"
	else
		CINC= "-DNOGTK" # not sure this is correct
	fi

	emake DESTDIR="${D}${INSTALLDIR}" \
		CINC="${CINC}" UPPDIR1="${UPPDIR1}" LIBS="${LIBS}" \
		all || die "make failed"
}

src_install() {
	cd ${WORKDIR}
	emake DESTDIR="${D}${INSTALLDIR}" \
		CINC="${CINC}" UPPDIR1="${UPPDIR1}" LIBS="${LIBS}" \
		install || die "make install failed"

	# now install add the path, etc., to the environment
	mkdir -p ${D}/etc/env.d
	echo -e "PATH=${INSTALLDIR}/bin\nROOTPATH=${INSTALLDIR}/bin" > \
		   ${D}/etc/env.d/60upp
}

pkg_postinst() {
	# link the 
	ln -sf ${INSTALLDIR}/bin/theide ${INSTALLDIR}/bin/upp
}

pkg_postrm() {
	# Get rid of those extraneous PATH entries.
	env-update
}
