# Copyright 1999-2007 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: $

inherit eutils toolchain-funcs

DESCRIPTION="Cross Platform Integrated Development Environment"
SRC_URI="http://downloads.sourceforge.net/upp/upp-src-2007.1rc2.zip"
HOMEPAGE="http://www.ultimatepp.org/"

#LICENSE="What License? GPL-2 LGPL-2.1"
LICENSE="GPL-2 LGPL-2.1"
SLOT="0"
KEYWORDS="~amd64 ~ppc ~sparc x86"

INSTALLDIR="/opt/upp"
UPPDIR1="${WORKDIR}/uppsrc/"
UPPOUT="${WORKDIR}/out/"
OutFile="${UPPOUT}/ide/GCC33-Gcc32-Gui-Linux-Main/ide"

IUSE="threads truetype gtk2"
DEPEND="gtk2? ( >=x11-libs/gtk+-2
					x11-libs/pango
					x11-libs/cairo
					dev-libs/atk )
				truetype? ( media-libs/freetype )
				media-libs/fontconfig"

src_unpack() {
	unpack ${A} || die "Unpacking ${A} failed!"

	einfo "Patching Makefiles..."

	# patches
	cd ${WORKDIR}
	epatch "${FILESDIR}/Makefile.ideb3r1.patch" || die
	epatch "${FILESDIR}/XPTheme.patch" || die
	epatch "${FILESDIR}/Install_rc1.patch" || die
	epatch "${FILESDIR}/libs.patch" || die
	epatch "${FILESDIR}/CC.patch" || die
}

src_compile() {
	cd ${UPPDIR1}/ide

	local CINC
	local LIBS
	local UPPDIR1
	local UPPOUT

	UPPDIR1="${WORKDIR}/uppsrc/"
	UPPOUT="${WORKDIR}/out/"

	CINC="-I${UPPDIR1}"
	LIBS=""
	if use truetype ; then
		CINC="${CINC} `freetype-config --cflags`"
		LIBS="${LIBS} `freetype-config --libs`"
	fi

	if use gtk2 ; then
		CINC="${CINC} `pkg-config gtk+-2.0 --cflags`"
		LIBS="${LIBS} `pkg-config gtk+-2.0 --libs`"
		CINC="${CINC} `pkg-config x11 --cflags`"
		LIBS="${LIBS} `pkg-config x11 --libs`"
		CINC="${CINC} `pkg-config libpng --cflags`"
		LIBS="${LIBS} `pkg-config libpng --libs`"
	else
		CINC= "-DNOGTK" # not sure this is correct
	fi

	emake DESTDIR="${D}${INSTALLDIR}" \
		CINC="${CINC}" UPPDIR1="${UPPDIR1}" UPPOUT="${UPPOUT}" \
		LIBS="${LIBS}" \
		all || die "make failed"
}

src_install() {
	cd ${WORKDIR}
	install -D ${OutFile} ${D}${INSTALLDIR}/bin/theide
	install -D ${UPPDIR1}/ide/GCC.bm ${D}${INSTALLDIR}/share/upp/GCC.bm
	cp -rf ${WORKDIR}/Common    ${D}${INSTALLDIR}/share/upp/
	cp -rf ${WORKDIR}/uppsrc    ${D}${INSTALLDIR}/share/upp/
	cp -rf ${WORKDIR}/examples  ${D}${INSTALLDIR}/share/upp/
	cp -rf ${WORKDIR}/reference ${D}${INSTALLDIR}/share/upp/
	cp -rf ${WORKDIR}/tutorial  ${D}${INSTALLDIR}/share/upp/

#	emake DESTDIR="${D}${INSTALLDIR}" \
#		CINC="${CINC}" UPPDIR1="${UPPDIR1}"  UPPOUT="${UPPOUT}" \
#		LIBS="${LIBS}" \
#		install || die "make install failed"

	# now install add the path, etc., to the environment
	mkdir -p ${D}/etc/env.d
	echo -e "PATH=${INSTALLDIR}/bin\nROOTPATH=${INSTALLDIR}/bin" > \
		   ${D}/etc/env.d/60upp
}

pkg_postinst() {
	# link the 
	ln -sf ${INSTALLDIR}/bin/theide ${INSTALLDIR}/bin/upp
}

pkg_postrm() {
	# Get rid of those extraneous PATH entries.
	env-update
}
